@@ -139,6 +139,8 @@ g_usb_device_error_quark(void);
 
 const gchar *
 g_usb_device_get_platform_id(GUsbDevice *self);
+gboolean
+g_usb_device_is_emulated(GUsbDevice *self);
 GUsbDevice *
 g_usb_device_get_parent(GUsbDevice *self);
 GPtrArray *
@@ -172,8 +174,12 @@ g_usb_device_get_device_protocol(GUsbDevice *self);
 
 void
 g_usb_device_add_tag(GUsbDevice *self, const gchar *tag);
+void
+g_usb_device_remove_tag(GUsbDevice *self, const gchar *tag);
 gboolean
 g_usb_device_has_tag(GUsbDevice *self, const gchar *tag);
+GPtrArray *
+g_usb_device_get_tags(GUsbDevice *self);
 
 guint8
 g_usb_device_get_configuration_index(GUsbDevice *self);
@@ -201,6 +207,8 @@ g_usb_device_get_interfaces(GUsbDevice *self, GError **error);
 
 GPtrArray *
 g_usb_device_get_events(GUsbDevice *self);
+void
+g_usb_device_clear_events(GUsbDevice *self);
 
 GPtrArray *
 g_usb_device_get_bos_descriptors(GUsbDevice *self, GError **error);
